/*
 * Kosmos.
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package hu.midori.kosmos.model;

import hu.midori.kosmos.model.util.TimestampedEntity;

import java.util.Date;

/**
 * Wraps a <i>SourceForge</i> release.
 *
 * @author <a href="mailto:aron.gombas@midori.hu">Aron Gombas</a>
 * @version $Id$
 */
public class SfRelease extends TimestampedEntity {
    /** Name of its package. */
    private String packageName;
    /** URL pointing to the package page on the SF site. */
    private String packageUrl;
    /** Version. */
    private String version;
    /** URL pointing to the version page on the SF site. */
    private String versionUrl;

    /**
     * By design this should be private to avoid instantiation
     * without discriminator, but Hessian needs default ctor.
     */
    public SfRelease() {
        super(null, null);
    }

    public SfRelease(String packageName, String packageUrl, String version, String versionUrl, Date releaseDate) {
        super(packageName + version + releaseDate.getTime(), releaseDate);

        this.packageName = packageName;
        this.packageUrl = packageUrl;
        this.version = version;
        this.versionUrl = versionUrl;
    }

    public String getPackageName() {
        return packageName;
    }

    public String getPackageUrl() {
        return packageUrl;
    }

    public String getVersion() {
        return version;
    }

    public String getVersionUrl() {
        return versionUrl;
    }

    public Date getReleaseDate() {
        return getDateCreated();
    }

    public String toString() {
        return String.format("%s %s", packageName, version);
    }
}
